@@ -2,7 +2,7 @@ import os
 import yaml
 import logging
 import subprocess
-from jinja2 import Environment, FileSystemLoader
+from jinja2 import Environment, PackageLoader, select_autoescape
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery, FileId, FileAppendTransaction, FileInfoQuery
 
 OPERATOR_ID= AccountId.fromString(os.environ["OPERATOR_ID"])
@@ -14,7 +14,7 @@ class network3_perseus():
         self.fileId=FILEID
 
     def configure_device(self):
-        self.get_file_from_hedera(self.fileId)
+        self.get_file_from_hedera()
         self.add_file_to_hedera("PRE-CHANGE STATE")
         self.pre_change=self.capture_state()
         self.push_config(self.yaml_contents)
@@ -32,6 +32,7 @@ class network3_perseus():
     def capture_state(self):
         self.output = subprocess.run(["python", "call_cli.py", "show running-config"], capture_output=True)
         raw_json=self.output.stdout.decode('utf-8')
+        self.append_file_to_hedera("POST-CHANGE STATE")
         for line in raw_json.split('\n'):
             print(line)
             self.append_file_to_hedera(f"{ line } \n")
@@ -40,8 +41,8 @@ class network3_perseus():
         print("File size according to `FileInfoQuery`: ", info.size)
 
     def push_config(self,yaml_contents):
-        template_dir = f'templates/cisco/nxos'
-        env = Environment(loader=FileSystemLoader(template_dir))
+        env = Environment(loader=PackageLoader("src/network3_perseus", "src/templates"))
+        autoescape=select_autoescape()
         intended_config_template = env.get_template('intended_config.j2')
         rendered_intended_config = intended_config_template.render(yaml_contents)
         subprocess.run(["python", "cli_configure.py", rendered_intended_config])
